Repository #
A Repository is a repository storing data of deployable plugins.
Package : spaceone.api.repository.v1
Repository #
Repository Methods:
register #
Registers a Repository. The parameter name can only include alphabets, numbers, and hyphens(-). The parameter repository_type can be either local or remote. The parameter endpoint is needed if the repository_type is remote.
POST /repository/v1/repository/register
name (string)
Requiredrepository_type (string)
Requireddomain_id (string)
Requiredendpoint (string)
{
"name": "Open Source Marketplace",
"repository_type": "remote",
"endpoint": "grpc+ssl://repository.portal.spaceone.megazone.io:443"
}repository_id (string)
Requiredname (string)
Requiredrepository_type (string)
Requiredendpoint (string)
Requiredcreated_at (string)
Required
{
"repository_id": "repo-123456789012",
"name": "Open Source Marketplace",
"repository_type": "remote",
"endpoint": "grpc+ssl://repository.portal.spaceone.megazone.io:443",
"created_at": "2022-01-01T02:27:02.924Z"
}update #
Updates a specific Repository registered. You must specify the repository_id of the Repository to update. You can make changes in Repository settings, including name.
POST /repository/v1/repository/update
repository_id (string)
Requireddomain_id (string)
Requiredname (string)
{
"repository_id": "repo-123456789012",
"name": "Changed Name"
}repository_id (string)
Requiredname (string)
Requiredrepository_type (string)
Requiredendpoint (string)
Requiredcreated_at (string)
Required
{
"repository_id": "repo-123456789012",
"name": "Open Source Marketplace",
"repository_type": "remote",
"endpoint": "grpc+ssl://repository.portal.spaceone.megazone.io:443",
"created_at": "2022-01-01T02:27:02.924Z"
}deregister #
Deregisters and deletes a specific Repository. You must specify the repository_id of the Repository to deregister.
POST /repository/v1/repository/deregister
repository_id (string)
Requireddomain_id (string)
Required
{
"repository_id": "repo-123456789012"
}get #
Gets a specific Repository. Prints detailed information about the Repository, including name, repository_type, and endpoint.
POST /repository/v1/repository/get
repository_id (string)
Requireddomain_id (string)
Requiredonly (string)
Repeated
{
"repository_id": "repo-123456789012"
}repository_id (string)
Requiredname (string)
Requiredrepository_type (string)
Requiredendpoint (string)
Requiredcreated_at (string)
Required
{
"repository_id": "repo-123456789012",
"name": "Open Source Marketplace",
"repository_type": "remote",
"endpoint": "grpc+ssl://repository.portal.spaceone.megazone.io:443",
"created_at": "2022-01-01T02:27:02.924Z"
}list #
Gets a list of all Repositories regardless of domain. You can use a query to get a filtered list of Repositories.
POST /repository/v1/repository/list
domain_id (string)
Requiredquery (Query)
repository_id (string)
name (string)
repository_type (string)
{
"query": {},
"repository_id": "repo-123456789012"
}results (RepositoryInfo)
RepeatedRequiredtotal_count (int32)
Required
{
"results": [
{
"repository_id": "repo-123456789012",
"name": "Open Source Marketplace",
"repository_type": "remote",
"endpoint": "grpc+ssl://repository.portal.spaceone.megazone.io:443",
"created_at": "2022-01-01T02:26:29.081Z"
}
],
"total_count": 1
}stat #
POST /repository/v1/repository/stat
Message #
CreateRepositoryRequest #
name (string)
Requiredrepository_type (string)
Requireddomain_id (string)
Requiredendpoint (string)
GetRepositoryRequest #
repository_id (string)
Requireddomain_id (string)
Requiredonly (string)
Repeated
RepositoriesInfo #
results (RepositoryInfo)
RepeatedRequiredtotal_count (int32)
Required
RepositoryInfo #
repository_id (string)
Requiredname (string)
Requiredrepository_type (string)
Requiredendpoint (string)
Requiredcreated_at (string)
Required
RepositoryQuery #
domain_id (string)
Requiredquery (Query)
repository_id (string)
name (string)
repository_type (string)
RepositoryRequest #
repository_id (string)
Requireddomain_id (string)
Required
RepositoryStatQuery #
query (StatisticsQuery)
Requireddomain_id (string)
Required
UpdateRepositoryRequest #
repository_id (string)
Requireddomain_id (string)
Requiredname (string)